==> haskell-primes-0.2.1.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-Iu8oh9qtE633xEUqJauSmw
key:                  primes-0.2.1.0-Iu8oh9qtE633xEUqJauSmw
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  18d62470d285099a6b03a452b8790a65
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-9.0.1/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/primes-0.2.1.0
hs-libraries:         HSprimes-0.2.1.0-Iu8oh9qtE633xEUqJauSmw
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primes-0.2.1.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primes
version:              0.2.1.0
visibility:           public
id:                   primes-0.2.1.0-40IDvqpKPw7IteoZuUfZEg
key:                  primes-0.2.1.0-40IDvqpKPw7IteoZuUfZEg
license:              BSD-3-Clause
maintainer:           Sebastian Fischer
author:               Sebastian Fischer
stability:            experimental
homepage:             http://github.com/sebfisch/primes
synopsis:             Efficient, purely functional generation of prime numbers
description:
    This Haskell library provides an efficient lazy wheel sieve for
    prime generation inspired by /Lazy wheel sieves and spirals of/
    /primes/ by Colin Runciman and /The Genuine Sieve of Eratosthenes/
    by Melissa O'\''Neil.

category:             Algorithms, Numerical
abi:                  a8116de30e32ffb9a45c93971bea7e9f
exposed:              True
exposed-modules:      Data.Numbers.Primes
import-dirs:          /usr/lib/ghc-9.0.2/site-local/primes-0.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primes-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/primes-0.2.1.0
hs-libraries:         HSprimes-0.2.1.0-40IDvqpKPw7IteoZuUfZEg
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-primes/html/primes.haddock
haddock-html:         /usr/share/doc/haskell-primes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
